@@ -10,7 +10,7 @@
 #' is a random variable with gamma distribution. Equivalence between different
 #' parameterizations are demonstrated below:
 #'
-#' ```{r, gamma_poisson_mixture, dev=c('svg','cairo_pdf'), fig.width=4, fig.height=4, fig.show='hide'}
+#' ```{r, gamma_poisson_mixture, dev='png', dpi = 160, fig.width=4, fig.height=4, fig.show='hide'}
 #' # Define constants and their relationships
 #' n <- 10000
 #' dispersion <- 8
@@ -67,12 +67,12 @@
 #' ```
 #'
 #' \if{html}{\out{<div style="display: flex; justify-content: center; padding-top: 10px; padding-bottom: 10px;">
-#'   <img style="max-width: 100\%; height: auto;" src="figures/gamma_poisson_mixture-1.svg" alt="Gamma-Poisson Mixture CDF" />
+#'   <img style="max-width: 400px; width: 100\%; height: auto;" src="figures/gamma_poisson_mixture-1.png" alt="Gamma-Poisson Mixture CDF" />
 #' </div>
 #' <br>}}
 #' \if{latex}{
 #'   \out{\begin{center}}
-#'   \figure{gamma_poisson_mixture-1.pdf}{options: width=3in}
+#'   \figure{gamma_poisson_mixture-1.png}{options: width=3in}
 #'   \out{\end{center}}
 #' }
 #'
@@ -143,11 +143,6 @@
 #'        value, the corresponding data is excluded from the set of simulations.
 #'        This is most likely to occur when the sample size is small and the
 #'        dispersion parameter is small.
-#' @param ncores (Scalar integer: `1L`; `[1,Inf)`)\cr
-#'        The number of cores (number of worker processes) to use. Do not set
-#'        greater than the value returned by [parallel::detectCores()]. May be
-#'        helpful when the number of parameter combinations is large and `nsims`
-#'        is large.
 #'
 #' @return If `nsims = 1` and the number of unique parameter combinations is
 #' one, the following objects are returned:
@@ -181,8 +176,7 @@
 #'   9 \tab `data` \tab List-column of simulated data.
 #' }
 #'
-#' @seealso [depower::sim_nb()], [stats::rpois()], [stats::rgamma()],
-#' [stats::rnbinom()]
+#' @seealso [depower::sim_nb()]
 #'
 #' @examples
 #' #----------------------------------------------------------------------------
@@ -287,43 +281,44 @@
 #'
 #' @export
 sim_bnb <- function(
-    n,
-    mean1,
-    mean2,
-    ratio,
-    dispersion,
-    nsims = 1L,
-    return_type = "list",
-    max_zeros = 0.99,
-    ncores = 1L
+  n,
+  mean1,
+  mean2,
+  ratio,
+  dispersion,
+  nsims = 1L,
+  return_type = "list",
+  max_zeros = 0.99
 ) {
   #-----------------------------------------------------------------------------
   # Check arguments
   #-----------------------------------------------------------------------------
-  if(!is.numeric(n) || any(n < 2L)) {
+  if (!is.numeric(n) || any(n < 2L)) {
     stop("Argument 'n' must be an integer vector from [2, Inf).")
   }
-  if(!is.numeric(mean1) || any(mean1 <= 0)) {
+  if (!is.numeric(mean1) || any(mean1 <= 0)) {
     stop("Argument 'mean1' must be a positive numeric vector.")
   }
 
   missing_mean2 <- missing(mean2)
   missing_ratio <- missing(ratio)
-  if(missing_mean2 && missing_ratio) {
+  if (missing_mean2 && missing_ratio) {
     stop("You must specify one of the arguments: 'mean2' or 'ratio'.")
   }
-  if(!missing_mean2 && !missing_ratio) {
-    stop("Arguments 'mean2' and 'ratio' were both specified. You may only specify one.")
+  if (!missing_mean2 && !missing_ratio) {
+    stop(
+      "Arguments 'mean2' and 'ratio' were both specified. You may only specify one."
+    )
   }
-  if(missing_ratio) {
-    if(!is.numeric(mean2) || any(mean2 <= 0)) {
+  if (missing_ratio) {
+    if (!is.numeric(mean2) || any(mean2 <= 0)) {
       stop("Argument 'mean2' must be a positive numeric vector.")
     }
     ratio_keep <- NULL # For filtering step below
     ratio <- NULL # For checking length(ratio)
   }
-  if(missing_mean2) {
-    if(!is.numeric(ratio) || any(ratio <= 0)) {
+  if (missing_mean2) {
+    if (!is.numeric(ratio) || any(ratio <= 0)) {
       stop("Argument 'ratio' must be a positive numeric vector.")
     }
     mean2 <- as.numeric(tcrossprod(ratio, mean1))
@@ -332,59 +327,55 @@ sim_bnb <- function(
     ratio_keep <- round(ratio, 5)
   }
 
-  if(!is.numeric(dispersion) || any(dispersion <= 0)) {
+  if (!is.numeric(dispersion) || any(dispersion <= 0)) {
     stop("Argument 'dispersion' must be a positive numeric vector.")
   }
-  if(!is.numeric(nsims) || length(nsims) != 1L || nsims < 1L) {
+  if (!is.numeric(nsims) || length(nsims) != 1L || nsims < 1L) {
     stop("Argument 'nsims' must be a positive scalar integer.")
   }
-  if(length(return_type) != 1L) {
+  if (length(return_type) != 1L) {
     stop("Argument 'return_type' must be one of 'list' or 'data.frame'.")
   }
-  data.frame <- switch(return_type,
+  data.frame <- switch(
+    return_type,
     "list" = FALSE,
     "data.frame" = TRUE,
     stop("Argument 'return_type' must be one of 'list' or 'data.frame'.")
   )
-  if(!is.numeric(max_zeros) || length(max_zeros) != 1L || max_zeros < 0 || max_zeros > 1) {
+  if (
+    !is.numeric(max_zeros) ||
+      length(max_zeros) != 1L ||
+      max_zeros < 0 ||
+      max_zeros > 1
+  ) {
     stop("Argument 'max_zeros' must be a scalar numeric from [0,1].")
   }
-  if(!is.numeric(ncores) || length(ncores) != 1L || ncores < 1L) {
-    stop("Argument 'ncores' must be a positive scalar integer.")
-  }
-  if(ncores > 1L) {
-    if(isTRUE(ncores > parallel::detectCores())) {
-      max <- parallel::detectCores()
-      warning("Argument 'ncores' should not be greater than ", max, ".")
-    }
-    cluster <- multidplyr::new_cluster(ncores)
-    multidplyr::cluster_library(cluster, 'depower')
-  }
 
-  needs_grid <- any(c(nsims, lengths(list(n, mean1, mean2, ratio, dispersion))) > 1L)
+  needs_grid <- any(
+    c(nsims, lengths(list(n, mean1, mean2, ratio, dispersion))) > 1L
+  )
 
   #-----------------------------------------------------------------------------
   # Simulate data
   #-----------------------------------------------------------------------------
-  res <- if(needs_grid) {
+  res <- if (needs_grid) {
     grid_bnb(
-      n = n,
+      n1 = n,
       mean1 = mean1,
       mean2 = mean2,
       ratio = ratio,
-      dispersion = dispersion,
+      dispersion1 = dispersion,
       nsims = nsims,
       data.frame = data.frame,
       max_zeros = max_zeros,
-      ncores = ncores,
       ratio_keep = ratio_keep
     )
   } else {
     sim_bnb_two_sample(
-      n = n,
+      n1 = n,
       mean1 = mean1,
       mean2 = mean2,
-      dispersion = dispersion,
+      dispersion1 = dispersion,
       nsims = nsims,
       data.frame = data.frame
     )
@@ -397,16 +388,15 @@ sim_bnb <- function(
 }
 
 grid_bnb <- function(
-    n,
-    mean1,
-    mean2,
-    ratio,
-    dispersion,
-    nsims,
-    data.frame,
-    max_zeros,
-    ncores,
-    ratio_keep
+  n1,
+  mean1,
+  mean2,
+  ratio,
+  dispersion1,
+  nsims,
+  data.frame,
+  max_zeros,
+  ratio_keep
 ) {
   #-----------------------------------------------------------------------------
   # Unique combinations for simulating data.
@@ -414,54 +404,55 @@ grid_bnb <- function(
   # mean1 and ratio are provided in function.
   #-----------------------------------------------------------------------------
   grid_sim <- expand.grid(
-    n1 = n,
+    n1 = n1,
     mean1 = mean1,
     mean2 = mean2,
-    dispersion1 = dispersion,
+    dispersion1 = dispersion1,
     nsims = nsims,
     distribution = "Dependent two-sample BNB",
     stringsAsFactors = FALSE
   ) |>
     dplyr::mutate(ratio = round(mean2 / mean1, 5), .after = "mean2") |>
-    {\(.) if(!is.null(ratio_keep)) {dplyr::filter(.data = ., ratio %in% ratio_keep)} else {.}}()
+    {
+      \(.) {
+        if (!is.null(ratio_keep)) {
+          dplyr::filter(.data = ., ratio %in% ratio_keep)
+        } else {
+          .
+        }
+      }
+    }()
 
   #-----------------------------------------------------------------------------
   # Simulate data
   #-----------------------------------------------------------------------------
-  if(ncores > 1L) {
-    cluster <- multidplyr::new_cluster(ncores)
-    multidplyr::cluster_library(cluster, 'depower')
-  }
-
   # Simulate data
   res <- grid_sim |>
     dplyr::rowwise() |>
-    {\(.) if(ncores > 1L) {multidplyr::partition(data = ., cluster = cluster)} else {.}}() |>
     dplyr::mutate(
       data = list(
         sim_bnb_two_sample(
-          n = n1,
+          n1 = n1,
           mean1 = mean1,
           mean2 = mean2,
-          dispersion = dispersion1,
+          dispersion1 = dispersion1,
           nsims = nsims,
           data.frame = data.frame
         )
       )
     ) |>
-    {\(.) if(ncores > 1L) {dplyr::collect(x = .)} else {.}}() |>
     dplyr::ungroup() |>
     dplyr::mutate(n2 = n1, .after = "n1")
 
   # Check if simulated data is all zeros or if the vast majority of data is all
   # zeros. This primarily occurs if you've selected a small dispersion (<0.1)
   # and have a small sample size.
-  if(any_zeros(res[["data"]], max_zeros)) {
+  if (any_zeros(res[["data"]], max_zeros)) {
     res <- res |>
       dplyr::rowwise() |>
       dplyr::mutate(
-        data = list(data[not_zeros(data, max_zeros)]),
-        nsims = length(data)
+        data = list(.data$data[not_zeros(.data$data, max_zeros)]),
+        nsims = length(.data$data)
       ) |>
       dplyr::ungroup()
   }
@@ -482,8 +473,10 @@ grid_bnb <- function(
     "Data" = "data"
   )
   idx <- match(names(res), vars)
-  if(anyNA(idx)) {stop("Unknown variable found while labeling data frame.")}
-  for(i in seq_len(ncol(res))) {
+  if (anyNA(idx)) {
+    stop("Unknown variable found while labeling data frame.")
+  }
+  for (i in seq_len(ncol(res))) {
     attr(res[[i]], "label") <- names(vars)[idx][i]
   }
 
@@ -497,40 +490,41 @@ grid_bnb <- function(
 }
 
 sim_bnb_two_sample <- function(
-    n,
-    mean1,
-    mean2,
-    dispersion,
-    nsims,
-    data.frame
+  n1,
+  mean1,
+  mean2,
+  dispersion1,
+  nsims,
+  data.frame
 ) {
   #-----------------------------------------------------------------------------
   # Simulate
   #-----------------------------------------------------------------------------
-  if(nsims > 1L) {
+  if (nsims > 1L) {
     res <- lapply(seq_len(nsims), function(x) {
-      g <- rgamma(n = n, shape = dispersion, scale = 1 / dispersion)
+      g <- rgamma(n = n1, shape = dispersion1, scale = 1 / dispersion1)
       mean1 <- mean1 * g
       mean2 <- mean2 * g
 
       list(
-        value1 = rpois(n = n, lambda = mean1),
-        value2 = rpois(n = n, lambda = mean2)
+        value1 = rpois(n = n1, lambda = mean1),
+        value2 = rpois(n = n1, lambda = mean2)
       )
     })
-    if(data.frame) {
+    if (data.frame) {
       res <- lapply(res, list_to_df)
     }
-  } else { # nsims == 1
-    g <- rgamma(n = n, shape = dispersion, scale = 1 / dispersion)
+  } else {
+    # nsims == 1
+    g <- rgamma(n = n1, shape = dispersion1, scale = 1 / dispersion1)
     mean1 <- mean1 * g
     mean2 <- mean2 * g
 
     res <- list(
-      value1 = rpois(n = n, lambda = mean1),
-      value2 = rpois(n = n, lambda = mean2)
+      value1 = rpois(n = n1, lambda = mean1),
+      value2 = rpois(n = n1, lambda = mean2)
     )
-    if(data.frame) {
+    if (data.frame) {
       res <- list_to_df(res)
     }
   }
@@ -540,5 +534,3 @@ sim_bnb_two_sample <- function(
   #-----------------------------------------------------------------------------
   res
 }
-
-utils::globalVariables(c("n1", "dispersion1", "data"))
