@@ -51,12 +51,45 @@
 #'
 #' Under \eqn{H_{null}}, the Wald test statistic is asymptotically distributed
 #' as \eqn{\chi^2_1}. The approximate level \eqn{\alpha} test rejects
-#' \eqn{H_{null}} if \eqn{W(f(\hat{r})) \geq \chi^2_1(1 - \alpha)}. Note that
+#' \eqn{H_{null}} if \eqn{W(f(\hat{r})) \geq \chi^2_1(1 - \alpha)}. However,
 #' the asymptotic critical value is known to underestimate the exact critical
-#' value. Hence, the nominal significance level may not be achieved for small
-#' sample sizes (possibly \eqn{n \leq 10} or \eqn{n \leq 50}). The level of
-#' significance inflation also depends on \eqn{f(\cdot)} and is most severe for
-#' \eqn{f(r) = r^2}, where only the exact critical value is recommended.
+#' value and the nominal significance level may not be achieved for small sample
+#' sizes. The level of significance inflation also depends on \eqn{f(\cdot)} and
+#' is most severe for \eqn{f(r) = r^2} where only the exact critical value
+#' should be used. Argument `distribution` allows control of the distribution of
+#' the \eqn{\chi^2_1} test statistic under the null hypothesis by use of
+#' functions [depower::asymptotic()] and [depower::simulated()].
+#'
+#' Note that standalone use of this function with `equal_dispersion = FALSE`
+#' and `distribution = simulated()`, e.g.
+#'
+#' ```{r, eval = FALSE}
+#' data |>
+#'   wald_test_nb(
+#'     equal_dispersion = FALSE,
+#'     distribution = simulated()
+#'   )
+#' ```
+#'
+#' results in a nonparametric randomization test based on label permutation.
+#' This violates the assumption of exchangeability for the randomization test
+#' because the labels are not exchangeable when the null hypothesis assumes
+#' unequal dispersions. However, used inside [depower::power()], e.g.
+#'
+#' ```{r, eval = FALSE}
+#' data |>
+#'   power(
+#'     wald_test_nb(
+#'       equal_dispersion = FALSE,
+#'       distribution = simulated()
+#'     )
+#'   )
+#' ```
+#'
+#' results in parametric resampling and no label permutation in performed.
+#' Thus, setting `equal_dispersion = FALSE` and `distribution = simulated()` is
+#' only recommended when [depower::wald_test_nb()] is used inside of
+#' [depower::power()]. See also, [depower::simulated()].
 #'
 #' @references
 #' \insertRef{rettiganti_2012}{depower}
@@ -79,11 +112,17 @@
 #' @param link (Scalar string: `"log"`)\cr
 #'        The one-to-one link function for transformation of the ratio in the
 #'        test hypotheses. Must be one of `"log"` (default), `"sqrt"`,
-#'        `"squared"`, or "`identity"`.
+#'        `"squared"`, or `"identity"`. See 'Details' for additional information.
 #' @param ratio_null (Scalar numeric: `1`; `(0, Inf)`)\cr
 #'        The (pre-transformation) ratio of means assumed under the null
 #'        hypothesis (group 2 / group 1). Typically `ratio_null = 1`
 #'        (no difference). See 'Details' for additional information.
+#' @param distribution (function: [depower::asymptotic()] or
+#'        [depower::simulated()])\cr
+#'        The method used to define the distribution of the \eqn{\chi^2} Wald
+#'        test statistic under the null hypothesis. See 'Details' and
+#'        [depower::asymptotic()] or [depower::simulated()] for additional
+#'        information.
 #' @param ... Optional arguments passed to the MLE function [depower::mle_nb()].
 #'
 #' @return
@@ -114,6 +153,8 @@
 #'   17 \tab \tab `mle_message` \tab Information from the optimizer.
 #' }
 #'
+#' @seealso [depower::lrt_nb()]
+#'
 #' @examples
 #' #----------------------------------------------------------------------------
 #' # wald_test_nb() examples
@@ -131,34 +172,52 @@
 #' ) |>
 #'   wald_test_nb()
 #'
-#' @importFrom stats pchisq
+#' @importFrom stats pchisq qnorm
 #'
 #' @export
 wald_test_nb <- function(
-    data,
-    equal_dispersion = FALSE,
-    ci_level = NULL,
-    link = "log",
-    ratio_null = 1,
-    ...
+  data,
+  equal_dispersion = FALSE,
+  ci_level = NULL,
+  link = "log",
+  ratio_null = 1,
+  distribution = asymptotic(),
+  ...
 ) {
   #-----------------------------------------------------------------------------
   # Check args
   #-----------------------------------------------------------------------------
-  if(!(is.list(data) && length(data) == 2L)) {
+  if (!(is.list(data) && length(data) == 2L)) {
     stop("Argument 'data' must be a list with 2 elements.")
   }
-  if(!(is.logical(equal_dispersion) && length(equal_dispersion) == 1L)) {
+  if (any(data[[1L]] < 0, na.rm = TRUE) || any(data[[2L]] < 0, na.rm = TRUE)) {
+    stop("Argument 'data' must not contain negative numbers.")
+  }
+  if (!(is.logical(equal_dispersion) && length(equal_dispersion) == 1L)) {
     stop("Argument 'equal_dispersion' must be a scalar logical.")
   }
-  if(!is.null(ci_level)) {
-    if(!is.numeric(ci_level) || length(ci_level) != 1L || ci_level <= 0 || ci_level >= 1) {
+  if (!is.null(ci_level)) {
+    if (
+      !is.numeric(ci_level) ||
+        length(ci_level) != 1L ||
+        ci_level <= 0 ||
+        ci_level >= 1
+    ) {
       stop("Argument 'ci_level' must be a scalar numeric from (0, 1).")
     }
   }
-  if(!(length(ratio_null) == 1L && ratio_null > 0)) {
+  if (!(length(ratio_null) == 1L && ratio_null > 0)) {
     stop("Argument 'ratio_null' must be a positive scalar numeric.")
   }
+  if (
+    !is.list(distribution) ||
+      length(distribution$distribution) != 1L ||
+      !distribution$distribution %in% c("asymptotic", "simulated")
+  ) {
+    stop(
+      "Argument 'distribution' must be a function from 'depower::asymptotic()' or 'depower::simulated()'."
+    )
+  }
 
   #-----------------------------------------------------------------------------
   # Get MLE
@@ -179,42 +238,82 @@ wald_test_nb <- function(
 
   sigma <- sqrt(
     mle_ratio *
-    (n1 * mle_dispersion1 * (mle_ratio * mle_mean1 + mle_dispersion2) +
-       n2 * mle_dispersion2 * mle_ratio * (mle_mean1 + mle_dispersion1)) /
-    (n1 * n2 * mle_dispersion1 * mle_dispersion2 * mle_mean1)
+      (n1 *
+        mle_dispersion1 *
+        (mle_ratio * mle_mean1 + mle_dispersion2) +
+        n2 * mle_dispersion2 * mle_ratio * (mle_mean1 + mle_dispersion1)) /
+      (n1 * n2 * mle_dispersion1 * mle_dispersion2 * mle_mean1)
   )
 
   # Link functions
-  linkf <- switch(link,
+  linkf <- switch(
+    link,
     "log" = log,
     "sqrt" = sqrt,
     "squared" = function(x) x^2,
     "identity" = function(x) x,
-    stop("Argument 'link' must be one of 'log', 'sqrt', 'squared', or 'identity'.")
+    stop(
+      "Argument 'link' must be one of 'log', 'sqrt', 'squared', or 'identity'."
+    )
   )
   # See ?D and ?deriv
-  derivative <- switch(link,
-    "log" = function(x) 1/x,
+  derivative <- switch(
+    link,
+    "log" = function(x) 1 / x,
     "sqrt" = function(x) 1 / (2 * sqrt(x)),
     "squared" = function(x) 2 * x,
     "identity" = function(x) 1,
-    stop("Argument 'link' must be one of 'log', 'sqrt', 'squared', or 'identity'.")
+    stop(
+      "Argument 'link' must be one of 'log', 'sqrt', 'squared', or 'identity'."
+    )
   )
-  inverse <- switch(link,
+  inverse <- switch(
+    link,
     "log" = exp,
     "sqrt" = function(x) x^2,
     "squared" = sqrt,
     "identity" = function(x) x,
-    stop("Argument 'link' must be one of 'log', 'sqrt', 'squared', or 'identity'.")
+    stop(
+      "Argument 'link' must be one of 'log', 'sqrt', 'squared', or 'identity'."
+    )
   )
 
   # Test statistic
-  wald_stat <- ((linkf(mle_ratio) - linkf(ratio_null)) / (derivative(mle_ratio) * sigma))^2
+  wald_stat <- ((linkf(mle_ratio) - linkf(ratio_null)) /
+    (derivative(mle_ratio) * sigma))^2
   wald_df <- 1L
-  wald_p <- pchisq(wald_stat, df = wald_df, lower.tail = FALSE)
+
+  # Randomization test if needed
+  wald_stat_null <- if (distribution$distribution == "simulated") {
+    if (is.null(distribution$test_stat_null)) {
+      test_stat_method <- "randomization"
+      call <- match.call()
+      randomize_tests(
+        data = data,
+        distribution = distribution,
+        paired = FALSE,
+        call = call
+      ) |>
+        extract(column = "result", element = "chisq", value = numeric(1L))
+    } else {
+      test_stat_method <- "parametric"
+      distribution$test_stat_null
+    }
+  } else {
+    test_stat_method <- NULL
+    NULL
+  }
+
+  # p-value
+  wald_p <- pchisq2(
+    q = wald_stat,
+    df = wald_df,
+    lower.tail = FALSE,
+    q_null = wald_stat_null
+  )
 
   # CI
-  if(is.null(ci_level)) {
+  if (is.null(ci_level)) {
     r_lower <- NA_real_
     r_upper <- NA_real_
   } else {
@@ -227,7 +326,11 @@ wald_test_nb <- function(
   #-----------------------------------------------------------------------------
   # Prepare result
   #-----------------------------------------------------------------------------
-  method <- "Wald test for independent negative binomial ratio of means"
+  method <- paste0(
+    str_to_title(distribution$method),
+    if (is.null(test_stat_method)) NULL else paste0(" ", test_stat_method),
+    " Wald test for independent negative binomial ratio of means"
+  )
   mle_code <- mle_alt[["mle_code"]]
   mle_message <- mle_alt[["mle_message"]]
 
